@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -32,10 +32,10 @@ class CardConnection(Observable):
 
     Known subclasses: smartcard.pcsc.PCSCCardConnection
     """
-    T0_protocol         = 0x00000001
-    T1_protocol         = 0x00000002
-    RAW_protocol        = 0x00010000
-    T15_protocol        = 0x00000008
+    T0_protocol = 0x00000001
+    T1_protocol = 0x00000002
+    RAW_protocol = 0x00010000
+    T15_protocol = 0x00000008
 
 
     def __init__( self, reader ):
@@ -70,7 +70,7 @@ class CardConnection(Observable):
         """Remove a CardConnection observer."""
         Observable.deleteObserver( self, observer )
 
-    def connect( self, protocol=None, mode=None ):
+    def connect( self, protocol=None, mode=None, disposition=None ):
         """Connect to card.
         protocol: a bit mask of the protocols to use, from CardConnection.T0_protocol, CardConnection.T1_protocol,
         CardConnection.RAW_protocol, CardConnection.T15_protocol
@@ -141,7 +141,7 @@ class CardConnection(Observable):
         Subclasses must override this method for implementing apdu transmission."""
         pass
 
-    def control( self, controlCode, bytes = [] ):
+    def control( self, controlCode, bytes=[] ):
         """Send a control command and buffer.  Internally calls doControl()
         class method and notify observers upon command/response events.
         Subclasses must override the doControl() class method.
@@ -164,4 +164,3 @@ class CardConnection(Observable):
 
         Subclasses must override this method for implementing control."""
         pass
-
