@@ -4,7 +4,7 @@ secure channel..
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -48,9 +48,9 @@ class CardConnectionDecorator( CardConnection ):
         """call inner component deleteObserver"""
         self.component.deleteObserver( observer )
 
-    def connect( self, protocol=None, mode=None ):
+    def connect( self, protocol=None, mode=None, disposition=None ):
         """call inner component connect"""
-        self.component.connect( protocol, mode )
+        self.component.connect( protocol, mode, disposition )
 
     def disconnect( self ):
         """call inner component disconnect"""
@@ -83,4 +83,3 @@ class CardConnectionDecorator( CardConnection ):
     def control( self, controlCode, bytes=[] ):
         """call inner component control"""
         return self.component.control( controlCode, bytes )
-
