@@ -8,7 +8,7 @@ upon reader insertion/removal.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -174,8 +174,10 @@ class CardMonitoringThread:
                 # by the __del__() method may already have been deleted.
                 # this causes ReaderMonitoringThread.run() to except with a TypeError
                 # or AttributeError
-                except TypeError: pass
-                except AttributeError: pass
+                except TypeError:
+                    pass
+                except AttributeError:
+                    pass
 
                 except:
                     try:
@@ -242,4 +244,3 @@ if __name__ == "__main__":
     t2 = testthread(2)
     t1.start()
     t2.start()
-
