@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -62,12 +62,13 @@ class __CardNames__(Synchronization):
             pass
 
     def dump( self ):
-        for k,v in self.db.iteritems():
+        for k, v in self.db.iteritems():
             print k, `loads(v)`
 
     def find( self, atr, reader=None ):
-        for k,v in self.db.iteritems():
-            if loads(v).matches( atr, reader ): return k
+        for k, v in self.db.iteritems():
+            if loads(v).matches( atr, reader ):
+                return k
                 
 
 synchronize( __CardNames__, "add delete dump find" )
@@ -103,4 +104,3 @@ if __name__ == '__main__':
     cn.delete( "Palmera Protect V2" )
     print '---------'
     cn.dump()
-
