@@ -7,7 +7,8 @@ Source: Robert Brewer at the Python Cookbook:
 http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/223972
 """
 
-import sys, types
+import sys
+import types
 
 def get_mod(modulePath):
     """Import a module."""
@@ -47,4 +48,3 @@ def get_class(fullClassName, parentClass=None):
 
     # Return a reference to the class itself, not an instantiated object.
     return aClass
-
