@@ -4,8 +4,10 @@ Sample for python PCSC wrapper module: get card ATR in first pcsc reader
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
+Copyright 2010 Ludovic Rousseau
+Author: Ludovic Rousseau, mailto:ludovic.rousseau@free.fr
 
 This file is part of pyscard.
 
@@ -28,16 +30,16 @@ from smartcard.scard import *
 import smartcard.util
 
 try:
-    hresult, hcontext = SCardEstablishContext( SCARD_SCOPE_USER )
-    if hresult!=0:
+    hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
+    if hresult != SCARD_S_SUCCESS:
         raise error, 'Failed to establish context: ' + SCardGetErrorMessage(hresult)
     print 'Context established!'
 
     try:
-        hresult, readers = SCardListReaders( hcontext, [] )
-        if hresult!=0:
+        hresult, readers = SCardListReaders(hcontext, [])
+        if hresult != SCARD_S_SUCCESS:
             raise error, 'Failed to list readers: ' + SCardGetErrorMessage(hresult)
-        if len(readers)<1:
+        if len(readers) < 1:
             raise Exception('No smart card readers')
         print 'PCSC Readers:', readers
 
@@ -45,16 +47,16 @@ try:
             print 'Trying to retreive ATR of card in', reader
 
             hresult, hcard, dwActiveProtocol = SCardConnect(
-                hcontext, reader, SCARD_SHARE_SHARED, SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1 )
-            if hresult!=0:
+                hcontext, reader, SCARD_SHARE_SHARED, SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1)
+            if hresult != SCARD_S_SUCCESS:
                 print 'Unable to connect: ' + SCardGetErrorMessage(hresult)
             else:
 
                 print 'Connected with active protocol', dwActiveProtocol
 
                 try:
-                    hresult, reader, state, protocol, atr = SCardStatus( hcard )
-                    if hresult!=0:
+                    hresult, reader, state, protocol, atr = SCardStatus(hcard)
+                    if hresult != SCARD_S_SUCCESS:
                         print 'failed to get status: ' + SCardGetErrorMessage(hresult)
                     print 'Reader:', reader
                     print 'State:', state
@@ -62,15 +64,15 @@ try:
                     print 'ATR:', smartcard.util.toHexString(atr, smartcard.util.HEX)
 
                 finally:
-                    hresult = SCardDisconnect( hcard, SCARD_UNPOWER_CARD )
-                    if hresult!=0:
+                    hresult = SCardDisconnect(hcard, SCARD_UNPOWER_CARD)
+                    if hresult != SCARD_S_SUCCESS:
                         print 'Failed to disconnect: ' + SCardGetErrorMessage(hresult)
                     print 'Disconnected'
 
 
     finally:
-        hresult = SCardReleaseContext( hcontext )
-        if hresult!=0:
+        hresult = SCardReleaseContext(hcontext)
+        if hresult != SCARD_S_SUCCESS:
             raise error, 'Failed to release context: ' + SCardGetErrorMessage(hresult)
         print 'Released context.'
 
@@ -79,7 +81,6 @@ except:
     print sys.exc_info()[0], ':', sys.exc_info()[1]
 
 import sys
-if 'win32'==sys.platform:
+if 'win32' == sys.platform:
     print 'press Enter to continue'
     sys.stdin.read(1)
-
