@@ -4,8 +4,10 @@ Sample for python PCSC wrapper module: List cards introduced in the system
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
+Copyright 2010 Ludovic Rousseau
+Author: Ludovic Rousseau, mailto:ludovic.rousseau@free.fr
 
 This file is part of pyscard.
 
@@ -26,41 +28,39 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 from smartcard.scard import *
 
-if 'winscard'==resourceManager:
+if 'winscard' == resourceManager:
     # Cryptoflex 8k v2 is introduced in standard Windows 2000
-    slbCryptoFlex8kv2ATR = [ 0x3B, 0x95, 0x15, 0x40, 0x00, 0x68, 0x01, 0x02, 0x00, 0x00  ]
+    slbCryptoFlex8kv2ATR = [0x3B, 0x95, 0x15, 0x40, 0x00, 0x68, 0x01, 0x02, 0x00, 0x00]
     try:
-        hresult, hcontext = SCardEstablishContext( SCARD_SCOPE_USER )
-        if hresult!=0:
+        hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
+        if hresult != SCARD_S_SUCCESS:
             raise error, 'Failed to establish context: ' + SCardGetErrorMessage(hresult)
         print 'Context established!'
 
         try:
-            hresult, card = SCardListCards( hcontext, slbCryptoFlex8kv2ATR, [] )
-            if hresult!=0:
+            hresult, card = SCardListCards(hcontext, slbCryptoFlex8kv2ATR, [])
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Failure to locate Schlumberger Cryptoflex 8k v2 card: ' + SCardGetErrorMessage(hresult)
             print 'Located by ATR:', card
 
-            hresult, cards = SCardListCards( hcontext, [], [] )
-            if hresult!=0:
+            hresult, cards = SCardListCards(hcontext, [], [])
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Failure to list cards: ' + SCardGetErrorMessage(hresult)
             print 'Cards:', cards
 
             for i in cards:
                 hresult, providerguid = SCardGetCardTypeProviderName(
-                                            hcontext,   i, SCARD_PROVIDER_PRIMARY )
-                if hresult==0:
+                    hcontext, i, SCARD_PROVIDER_PRIMARY)
+                if hresult == SCARD_S_SUCCESS:
                     print i, 'Primary provider:', providername
                 hresult, providername = SCardGetCardTypeProviderName(
-                                            hcontext,   i, SCARD_PROVIDER_CSP )
-                if hresult==0:
+                    hcontext, i, SCARD_PROVIDER_CSP)
+                if hresult == SCARD_S_SUCCESS:
                     print i, 'CSP Provider:', providername
 
-
-
         finally:
-            hresult = SCardReleaseContext( hcontext )
-            if hresult!=0:
+            hresult = SCardReleaseContext(hcontext)
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Failed to release context: ' + SCardGetErrorMessage(hresult)
             print 'Released context.'
 
@@ -68,12 +68,11 @@ if 'winscard'==resourceManager:
         import sys
         print sys.exc_info()[0], ':', sys.exc_info()[1]
 
-elif 'pcsclite'==resourceManager:
+elif 'pcsclite' == resourceManager:
     print 'SCardListCards not supported by pcsc lite'
 
 
 import sys
-if 'win32'==sys.platform:
+if 'win32' == sys.platform:
     print 'press Enter to continue'
     sys.stdin.read(1)
-
