@@ -4,8 +4,10 @@ Sample for python PCSC wrapper module: illustrate reader groups functions
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
+Copyright 2010 Ludovic Rousseau
+Author: Ludovic Rousseau, mailto:ludovic.rousseau@free.fr
 
 This file is part of pyscard.
 
@@ -29,93 +31,92 @@ from smartcard.scard import *
 newgroup = 'MyReaderGroup'
 
 try:
-    hresult, hcontext = SCardEstablishContext( SCARD_SCOPE_USER )
-    if hresult!=0:
+    hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
+    if hresult != SCARD_S_SUCCESS:
         raise error, 'Failed to establish context: ' + SCardGetErrorMessage(hresult)
     print 'Context established!'
 
     try:
-        hresult, readers = SCardListReaders( hcontext, [] )
-        if hresult!=0:
+        hresult, readers = SCardListReaders(hcontext, [])
+        if hresult != SCARD_S_SUCCESS:
             raise error, 'Failed to list readers: ' + SCardGetErrorMessage(hresult)
         print 'PCSC Readers in all groups:', readers
 
-        hresult, readerGroups = SCardListReaderGroups( hcontext )
-        if hresult!=0:
+        hresult, readerGroups = SCardListReaderGroups(hcontext)
+        if hresult != SCARD_S_SUCCESS:
             raise error, 'Unable to list reader groups: ' + SCardGetErrorMessage(hresult)
         print 'PCSC Reader groups:', readerGroups
 
-        if 'winscard'==resourceManager:
+        if 'winscard' == resourceManager:
 
-            hresult = SCardIntroduceReaderGroup( hcontext, newgroup )
-            if hresult!=0:
+            hresult = SCardIntroduceReaderGroup(hcontext, newgroup)
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Unable to introduce reader group: ' + SCardGetErrorMessage(hresult)
 
             dummyreader = readers[0] + ' dummy'
-            hresult = SCardIntroduceReader( hcontext, dummyreader, readers[0] )
-            if hresult!=0:
+            hresult = SCardIntroduceReader(hcontext, dummyreader, readers[0])
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Unable to introduce reader: ' + dummyreader + ' : ' + SCardGetErrorMessage(hresult)
 
-            hresult, readers = SCardListReaders( hcontext, [] )
-            if hresult!=0:
+            hresult, readers = SCardListReaders(hcontext, [])
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Failed to list readers: ' + SCardGetErrorMessage(hresult)
             print 'PCSC Readers in all groups:', readers
 
-            hresult = SCardAddReaderToGroup( hcontext, dummyreader, newgroup )
-            if hresult!=0:
+            hresult = SCardAddReaderToGroup(hcontext, dummyreader, newgroup)
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Unable to add reader to group: ' + SCardGetErrorMessage(hresult)
 
-            hresult, readerGroups = SCardListReaderGroups( hcontext )
-            if hresult!=0:
+            hresult, readerGroups = SCardListReaderGroups(hcontext)
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Unable to list reader groups: ' + SCardGetErrorMessage(hresult)
             print 'PCSC Reader groups:', readerGroups
 
-            hresult, readers = SCardListReaders( hcontext, [newgroup] )
-            if hresult!=0:
+            hresult, readers = SCardListReaders(hcontext, [newgroup])
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Failed to list readers in group ' + newgroup + ' : ' + SCardGetErrorMessage(hresult)
             print 'PCSC Readers in reader group', newgroup, ':', readers
 
-            hresult = SCardRemoveReaderFromGroup( hcontext, dummyreader, newgroup )
-            if hresult!=0:
+            hresult = SCardRemoveReaderFromGroup(hcontext, dummyreader, newgroup)
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Unable to remove reader from group: ' + SCardGetErrorMessage(hresult)
 
-            hresult, readerGroups = SCardListReaderGroups( hcontext )
-            if hresult!=0:
+            hresult, readerGroups = SCardListReaderGroups(hcontext)
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Unable to list reader groups: ' + SCardGetErrorMessage(hresult)
             print 'PCSC Reader groups:', readerGroups
 
-            hresult = SCardForgetReaderGroup( hcontext, newgroup )
-            if hresult!=0:
+            hresult = SCardForgetReaderGroup(hcontext, newgroup)
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Unable to forget reader group: ' + SCardGetErrorMessage(hresult)
 
-            hresult = SCardForgetReader( hcontext, dummyreader )
-            if hresult!=0:
+            hresult = SCardForgetReader(hcontext, dummyreader)
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Failed to forget readers ' + SCardGetErrorMessage(hresult)
 
-            hresult, readers = SCardListReaders( hcontext, [] )
-            if hresult!=0:
+            hresult, readers = SCardListReaders(hcontext, [])
+            if hresult != SCARD_S_SUCCESS:
                 raise error, 'Failed to list readers: ' + SCardGetErrorMessage(hresult)
             print 'PCSC Readers in all groups:', readers
 
-        elif 'pcsclite'==resourceManager:
-            hresult, readers = SCardListReaders( hcontext, readerGroups )
-            if hresult!=0:
-                raise error, 'Failed to list readers in groups '+ `readerGroups` + ' : ' + SCardGetErrorMessage(hresult)
+        elif 'pcsclite' == resourceManager:
+            hresult, readers = SCardListReaders(hcontext, readerGroups)
+            if hresult != SCARD_S_SUCCESS:
+                raise error, 'Failed to list readers in groups ' + `readerGroups` + ' : ' + SCardGetErrorMessage(hresult)
             print 'PCSC Readers in reader group', readerGroups, ':', readers
 
 
     finally:
-        hresult = SCardReleaseContext( hcontext )
-        if hresult!=0:
+        hresult = SCardReleaseContext(hcontext)
+        if hresult != SCARD_S_SUCCESS:
             raise error, 'Failed to release context: ' + SCardGetErrorMessage(hresult)
         print 'Released context.'
 
     import sys
-    if 'win32'==sys.platform:
+    if 'win32' == sys.platform:
         print 'press Enter to continue'
         sys.stdin.read(1)
 
 except error:
     import sys
     print sys.exc_info()[0], ':', sys.exc_info()[1]
-
