@@ -4,8 +4,10 @@ Sample for python PCSC wrapper module: perform a simple transaction
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
+Copyright 2010 Ludovic Rousseau
+Author: Ludovic Rousseau, mailto:ludovic.rousseau@free.fr
 
 This file is part of pyscard.
 
@@ -26,20 +28,19 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 from smartcard.scard import *
 
-
 try:
-    hresult, hcontext = SCardEstablishContext( SCARD_SCOPE_USER )
-    if hresult!=0:
+    hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
+    if hresult != SCARD_S_SUCCESS:
         raise error, 'Failed to establish context: ' + SCardGetErrorMessage(hresult)
     print 'Context established!'
 
     try:
-        hresult, readers = SCardListReaders( hcontext, [] )
-        if hresult!=0:
+        hresult, readers = SCardListReaders(hcontext, [])
+        if hresult != SCARD_S_SUCCESS:
             raise error, 'Failed to list readers:: ' + SCardGetErrorMessage(hresult)
         print 'PCSC Readers:', readers
 
-        if len(readers)<1:
+        if len(readers) < 1:
             raise error, 'No smart card readers'
 
         for zreader in readers:
@@ -48,18 +49,18 @@ try:
             try:
                 hresult, hcard, dwActiveProtocol = SCardConnect(
                     hcontext, zreader, SCARD_SHARE_SHARED, SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1)
-                if hresult!=0:
+                if hresult != SCARD_S_SUCCESS:
                     raise error, 'unable to connect: ' + SCardGetErrorMessage(hresult)
                 print 'Connected with active protocol', dwActiveProtocol
 
                 try:
-                    hresult = SCardBeginTransaction( hcard )
-                    if hresult!=0:
+                    hresult = SCardBeginTransaction(hcard)
+                    if hresult != SCARD_S_SUCCESS:
                         raise error, 'failed to begin transaction: ' + SCardGetErrorMessage(hresult)
                     print 'Beginning transaction'
 
-                    hresult, reader, state, protocol, atr = SCardStatus( hcard )
-                    if hresult!=0:
+                    hresult, reader, state, protocol, atr = SCardStatus(hcard)
+                    if hresult != SCARD_S_SUCCESS:
                         raise error, 'failed to get status: ' + SCardGetErrorMessage(hresult)
                     print 'ATR:',
                     for i in xrange(len(atr)):
@@ -67,21 +68,21 @@ try:
                     print ""
 
                 finally:
-                    hresult = SCardEndTransaction( hcard, SCARD_LEAVE_CARD )
-                    if hresult!=0:
+                    hresult = SCardEndTransaction(hcard, SCARD_LEAVE_CARD)
+                    if hresult != SCARD_S_SUCCESS:
                         raise error, 'failed to end transaction: ' + SCardGetErrorMessage(hresult)
                     print 'Transaction ended'
 
-                    hresult = SCardDisconnect( hcard, SCARD_UNPOWER_CARD )
-                    if hresult!=0:
+                    hresult = SCardDisconnect(hcard, SCARD_UNPOWER_CARD)
+                    if hresult != SCARD_S_SUCCESS:
                         raise error, 'failed to disconnect: ' + SCardGetErrorMessage(hresult)
                     print 'Disconnected'
             except error, (message):
                 print error, message
 
     finally:
-        hresult = SCardReleaseContext( hcontext )
-        if hresult!=0:
+        hresult = SCardReleaseContext(hcontext)
+        if hresult != SCARD_S_SUCCESS:
             raise error, 'failed to release context: ' + SCardGetErrorMessage(hresult)
         print 'Released context.'
 
@@ -90,7 +91,6 @@ except error:
     print sys.exc_info()[0], ':', sys.exc_info()[1]
 
 import sys
-if 'win32'==sys.platform:
+if 'win32' == sys.platform:
     print 'press Enter to continue'
     sys.stdin.read(1)
-
