@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -35,14 +35,15 @@ class ExclusiveConnectCardConnection( CardConnectionDecorator ):
     def __init__( self, cardconnection ):
         CardConnectionDecorator.__init__( self, cardconnection )
 
-    def connect( self, protocol=None, mode=None ):
+    def connect( self, protocol=None, mode=None, disposition=None ):
         '''Disconnect and reconnect in exclusive mode PCSCCardconnections.'''
-        CardConnectionDecorator.connect( self, protocol, mode )
+        CardConnectionDecorator.connect( self, protocol, mode, disposition )
         component=self.component
         while True:
             if isinstance( component, smartcard.pcsc.PCSCCardConnection.PCSCCardConnection ):
                 pcscprotocol = PCSCCardConnection.translateprotocolmask( protocol )
-                if 0==pcscprotocol: pcscprotocol = component.getProtocol()
+                if 0==pcscprotocol:
+                    pcscprotocol = component.getProtocol()
 
                 if None!=component.hcard:
                     hresult = SCardDisconnect( component.hcard, SCARD_LEAVE_CARD )
