@@ -8,7 +8,7 @@ upon reader insertion/removal.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -167,7 +167,8 @@ class ReaderMonitoringThread(Thread):
                         if addedReaders or removedReaders:
                             # Notify observers
                             self.readers=[]
-                            for r in currentReaders: self.readers.append(r)
+                            for r in currentReaders:
+                                self.readers.append(r)
                             self.observable.setChanged()
                             self.observable.notifyObservers((addedReaders, removedReaders))
     
@@ -218,4 +219,3 @@ if __name__ == "__main__":
     t2.start()
     t1.join()
     t2.join()
-
