@@ -4,10 +4,10 @@ The smartcard utility module provides classes and functions to
 access smartcards and readers.
 
 __author__ = "gemalto http://www.gemalto.com"
-__date__ = "August 2008"
-__version__ = "1.6.7"
+__date__ = "May 2010"
+__version__ = "1.6.10"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -36,4 +36,3 @@ __all__ = [
 # for legacy only
 from smartcard.System import listReaders
 from smartcard.Session import Session
-
