@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -82,7 +82,7 @@ class PCSCCardConnection( CardConnection ):
             raise CardConnectionException( 'Failed to release context: ' + SCardGetErrorMessage(hresult) )
         CardConnection.__del__( self )
 
-    def connect( self, protocol=None, mode=None ):
+    def connect( self, protocol=None, mode=None, disposition=None ):
         """Connect to the card.
         
         If protocol is not specified, connect with the default connection protocol.
@@ -90,9 +90,17 @@ class PCSCCardConnection( CardConnection ):
         If mode is not specified, connect with SCARD_SHARE_SHARED."""
         CardConnection.connect( self, protocol )
         pcscprotocol = translateprotocolmask( protocol )
-        if 0==pcscprotocol: pcscprotocol = self.getProtocol()
+        if 0==pcscprotocol:
+            pcscprotocol = self.getProtocol()
+
+        if mode==None:
+            mode = SCARD_SHARE_SHARED
+
+        # store the way to dispose the card
+        if disposition==None:
+            disposition = SCARD_UNPOWER_CARD
+        self.disposition = disposition
 
-        if mode==None: mode = SCARD_SHARE_SHARED
         hresult, self.hcard, dwActiveProtocol = SCardConnect(
             self.hcontext, str(self.reader), mode, pcscprotocol )
         if hresult!=0:
@@ -119,7 +127,7 @@ class PCSCCardConnection( CardConnection ):
         except TypeError:
             pass
         if None!=self.hcard:
-            hresult = SCardDisconnect( self.hcard, SCARD_UNPOWER_CARD )
+            hresult = SCardDisconnect( self.hcard, self.disposition )
             if hresult!=0:
                 raise CardConnectionException( 'Failed to disconnect: ' + SCardGetErrorMessage(hresult) )
             self.hcard = None
