@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -22,7 +22,8 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
-import threading, time
+import threading
+import time
 
 from smartcard.AbstractCardRequest import AbstractCardRequest
 from smartcard.Exceptions import CardRequestTimeoutException, CardRequestException, ListReadersException
@@ -106,8 +107,10 @@ class PCSCCardRequest(AbstractCardRequest):
 
         # for non infinite timeout, a timer will signal the end of the time-out by setting the evt event
         evt = threading.Event()
-        if INFINITE==self.timeout: timertimeout=1
-        else: timertimeout=self.timeout
+        if INFINITE==self.timeout:
+            timertimeout=1
+        else:
+            timertimeout=self.timeout
         timer = threading.Timer( timertimeout, signalEvent, [evt, INFINITE==self.timeout] )
 
         # create a dictionary entry for new readers
@@ -134,7 +137,13 @@ class PCSCCardRequest(AbstractCardRequest):
         if 0!=hresult and SCARD_E_TIMEOUT!=hresult and SCARD_E_UNKNOWN_READER!=hresult:
                 raise CardRequestException( 'Failed to SCardGetStatusChange ' + SCardGetErrorMessage(hresult) )
 
-
+        # in case of timeout or reader disappearing, the content of the states is useless
+        # in which case we clear the changed bit
+        if SCARD_E_TIMEOUT==hresult or SCARD_E_UNKNOWN_READER==hresult:
+            for state in newstates:
+                state[1] = state[1] & (0xFFFFFFFF ^ SCARD_STATE_CHANGED)
+    
+    
         # update readerstate
         for state in newstates:
             readername, eventstate, atr = state
@@ -223,7 +232,8 @@ class PCSCCardRequest(AbstractCardRequest):
                     # update state dictionary
                     readerstates[readername] = ( readername, eventstate )
 
-            if evt.isSet(): raise CardRequestTimeoutException()
+            if evt.isSet():
+                raise CardRequestTimeoutException()
 
 
 
@@ -234,8 +244,10 @@ class PCSCCardRequest(AbstractCardRequest):
         evt = threading.Event()
 
         # for non infinite timeout, a timer will signal the end of the time-out
-        if INFINITE==self.timeout: timertimeout=1
-        else: timertimeout=self.timeout
+        if INFINITE==self.timeout:
+            timertimeout=1
+        else:
+            timertimeout=self.timeout
         timer = threading.Timer( timertimeout, signalEvent, [evt, INFINITE==self.timeout] )
 
         # get status change until time-out, e.g. evt is set
@@ -300,7 +312,8 @@ class PCSCCardRequest(AbstractCardRequest):
                         presentcards.append( Card.Card( readername, atr ) )
                 return presentcards
 
-        if evt.isSet(): raise CardRequestTimeoutException()
+        if evt.isSet():
+            raise CardRequestTimeoutException()
 
 if __name__ == '__main__':
     """Small sample illustrating the use of PCSCCardRequest.py."""
@@ -312,4 +325,3 @@ if __name__ == '__main__':
     cs.connection.connect()
     print cs.connection.getReader(), toHexString(cs.connection.getATR())
     cs.connection.disconnect()
-
