@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -45,14 +45,13 @@ class PCSCContext:
     instance = None
 
     def __init__( self ):
-        PCSCContext.mutex.acquire();
+        PCSCContext.mutex.acquire()
         try:
             if not PCSCContext.instance:
                 PCSCContext.instance = PCSCContext.__PCSCContextSingleton()
         finally:
-            PCSCContext.mutex.release();
+            PCSCContext.mutex.release()
 
     def __getattr__( self, name ):
         if self.instance:
             return getattr( self.instance, name )
-
