@@ -2,7 +2,7 @@
 
 __author__ = "gemalto http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -38,7 +38,8 @@ def __PCSCreaders__( hcontext, groups=[] ):
     """
 
     # in case we have a string instead of a list
-    if isinstance( groups, type("")): groups=[groups]
+    if isinstance( groups, type("")):
+        groups=[groups]
     hresult, readers = SCardListReaders( hcontext, groups )
     if hresult!=0:
         if hresult==SCARD_E_NO_READERS_AVAILABLE:
@@ -115,4 +116,3 @@ if __name__ == '__main__':
     cc.connect()
     data, sw1, sw2 = cc.transmit( SELECT + DF_TELECOM )
     print "%X %X" % (sw1, sw2)
-
