@@ -6,7 +6,7 @@ thru testsuite_framework.py.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -83,8 +83,10 @@ class testcase_ErrorChecking(unittest.TestCase):
         except excClass, e:
             return e
         else:
-            if hasattr(excClass,'__name__'): excName = excClass.__name__
-            else: excName = str(excClass)
+            if hasattr(excClass,'__name__'):
+                excName = excClass.__name__
+            else:
+                excName = str(excClass)
             raise self.failureException, excName
 
 
@@ -280,4 +282,3 @@ def suite():
 
 if __name__ == '__main__':
     unittest.main()
-
