@@ -2,7 +2,7 @@
 
 __author__ = "gemalto http://www.gemalto.com"
 
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -42,7 +42,7 @@ class BaseCardTreeCtrl( wx.TreeCtrl ):
                   ID=wx.NewId(),
                   pos=wx.DefaultPosition,
                   size=wx.DefaultSize,
-                  style= 0,
+                  style=0,
                   clientpanel=None ):
         """Constructor. Initializes a smartcard or reader tree control."""
         wx.TreeCtrl.__init__( self, parent, ID, pos, size , wx.TR_SINGLE | wx.TR_NO_BUTTONS )
@@ -75,7 +75,7 @@ class CardTreeCtrl( BaseCardTreeCtrl ):
                   ID=wx.NewId(),
                   pos=wx.DefaultPosition,
                   size=wx.DefaultSize,
-                  style= 0,
+                  style=0,
                   clientpanel=None ):
         """Constructor. Create a smartcard tree control."""
         BaseCardTreeCtrl.__init__( self, parent, ID, pos, size ,
@@ -125,7 +125,7 @@ class ReaderTreeCtrl( BaseCardTreeCtrl ):
                   ID=wx.NewId(),
                   pos=wx.DefaultPosition,
                   size=wx.DefaultSize,
-                  style= 0,
+                  style=0,
                   clientpanel=None ):
         """Constructor. Create a reader tree control."""
 
@@ -197,7 +197,7 @@ class ReaderTreeCtrl( BaseCardTreeCtrl ):
 
             self.Expand(self.root)
         finally:
-            self.mutex.release();
+            self.mutex.release()
         self.EnsureVisible( self.root )
         self.Repaint()
 
@@ -226,7 +226,7 @@ class ReaderTreeCtrl( BaseCardTreeCtrl ):
                     self.Expand(childReader)
             self.Expand(self.root)
         finally:
-            self.mutex.release();
+            self.mutex.release()
         self.EnsureVisible( self.root )
         self.Repaint()
 
@@ -249,7 +249,7 @@ class ReaderTreeCtrl( BaseCardTreeCtrl ):
                         ( childReader, cookie ) = self.GetNextChild( parentnode, cookie )
             self.Expand(self.root)
         finally:
-            self.mutex.release();
+            self.mutex.release()
         self.EnsureVisible( self.root )
         self.Repaint()
 
@@ -268,7 +268,7 @@ class ReaderTreeCtrl( BaseCardTreeCtrl ):
                         ( childReader, cookie ) = self.GetNextChild( parentnode, cookie )
             self.Expand(self.root)
         finally:
-            self.mutex.release();
+            self.mutex.release()
         self.EnsureVisible( self.root )
         self.Repaint()
 
@@ -360,4 +360,3 @@ class CardAndReaderTreePanel( wx.Panel ):
             self.readermonitor.deleteObserver( self.readertreereaderobserver )
             self.cardmonitor.deleteObserver( self.readertreecardobserver )
         event.Skip()
-
